@@ -3,7 +3,7 @@
 #
 #  install-loook.sh
 #  
-#  Copyright 2013 Mechtilde Stehmann
+#  Copyright 2013,2014 Mechtilde Stehmann
 #  
 #  This program is free software; you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -37,13 +37,16 @@ then
         chmod +x $InstP/loook.py &&
 
         mkdir -pv $InstP/locale/en/LC_MESSAGES/ &&
-        cp -av locale/en/LC_MESSAGES/loook-0.7.3.mo $InstP/locale/en/LC_MESSAGES/loook-0.7.3.mo &&
+        cp -av locale/en/LC_MESSAGES/loook-0.8.0.mo $InstP/locale/en/LC_MESSAGES/loook-0.8.0.mo &&
 
         mkdir -pv $InstP/locale/de/LC_MESSAGES/ &&
-        cp -av locale/de/LC_MESSAGES/loook-0.7.3.mo $InstP/locale/de/LC_MESSAGES/loook-0.7.3.mo &&
+        cp -av locale/de/LC_MESSAGES/loook-0.8.0.mo $InstP/locale/de/LC_MESSAGES/loook-0.8.0.mo &&
         
         mkdir -pv $InstP/locale/nl/LC_MESSAGES/ &&
-        cp -av locale/nl/LC_MESSAGES/loook-0.7.3.mo $InstP/locale/nl/LC_MESSAGES/loook-0.7.3.mo &&
+        cp -av locale/nl/LC_MESSAGES/loook-0.8.0.mo $InstP/locale/nl/LC_MESSAGES/loook-0.8.0.mo &&
+        
+        mkdir -pv $InstP/locale/it/LC_MESSAGES/ &&
+        cp -av locale/it/LC_MESSAGES/loook-0.8.0.mo $InstP/locale/it/LC_MESSAGES/loook-0.8.0.mo &&
 
         ln -sv $InstP/loook.py /usr/local/bin/loook &&
 
