@@ -2,9 +2,9 @@
 # -*- coding: utf-8 -*-
 #
 #	Copyright (C) 2003-2010 Daniel Naber, Lutz Haseloff
-#   Copyright (C) 2013 Mechtilde Stehmann
+#	Copyright (C) 2013-2014 Mechtilde Stehmann
 #
-#	Copyright (C) 2013 for the gettext integration: Dr. Michael Stehmann
+#	Copyright (C) 2013-2014 for the gettext integration: Dr. Michael Stehmann
 #
 #	This program is free software; you can redistribute it and/or
 #	modify it under the terms of the GNU General Public License
@@ -19,7 +19,7 @@
 #	You should have received a copy of the GNU General Public License
 #	along with this program; if not, write to the Free Software
 #	Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
-#   MA 02110-1301, USA.
+#	MA 02110-1301, USA.
 
 import configparser
 import codecs
@@ -138,8 +138,13 @@ class Application(object):
 		self.stop_button["command"] = self.stop
 		self.stop_button["state"] = DISABLED
 		self.stop_button.pack(side=RIGHT)
-		f.grid(row=5, columnspan=2, column=2, sticky=E, pady=pad, padx=pad)
+		self.save_button = Button(f)
+		self.save_button["text"] = _("Save")
+		self.save_button["command"] = self.doSave 
+		self.save_button["state"] = DISABLED
+		self.save_button.pack(side=LEFT)
 
+		f.grid(row=5, column=2, sticky=E, pady=pad, padx=pad)
 		self.status = Label(self.master, text="", bd=1, relief=SUNKEN, anchor=W)
 		self.status.config(text=_("Ready."))
 		self.status.grid(row=6, columnspan=4, column=0, sticky=E+W, pady=pad, padx=pad)
@@ -340,6 +345,36 @@ class Application(object):
 					title = title_match.group(1)
 				if self.match(query, "%s %s" % (content.lower(), docinfo.lower())):
 					return (filename, title)
+			# Handle MS-Office (>= 2007) MS-PowerPoint files:
+			if suffix in ('pptx', 		# MS-PowerPoint-Documents >= 2007
+				):
+				zip = zipfile.ZipFile(filename, "r")
+				content = ""
+				docinfo = ""
+				try:
+					# search embedded files:
+					filelist = zip.namelist()
+					slideslist = []
+					for element in filelist:
+						if element[4:12]  == "slides/s":
+							slideslist.append(element)
+					content =""
+					for element in slideslist:
+						content += str(zip.read(element), 'utf-8')
+
+					content = self.removeXMLMarkup(content, replace_with_space=0)
+					docinfo = str(zip.read("docProps/core.xml"), 'utf-8')
+					docinfo = self.removeXMLMarkup(docinfo, replace_with_space=0)
+				except KeyError as err:
+					print("Warning: %s not found in '%s'" % (err, filename))
+					return None
+				title = ""
+				title_match = re.compile("<dc:title>(.*?)</dc:title>", re.DOTALL|re.IGNORECASE).search(docinfo)
+				if title_match:
+					title = title_match.group(1)
+				if self.match(query, "%s %s" % (content.lower(), docinfo.lower())):
+					return (filename, title)
+				self.ooo_count = self.ooo_count + 1
 
 		except zipfile.BadZipfile as err:
 			print(_("Warning: Supposed ZIP file ") + filename + _("could not be opened: ") + err)
@@ -352,6 +387,7 @@ class Application(object):
 		self.last_update = 0
 		self.match_count = 0
 		self.ooo_count = 0
+		self.savestring = ""
 		self.listbox.delete(0, END)
 		self.stop_button["state"] = NORMAL
 		self.quit_button["state"] = DISABLED
@@ -396,8 +432,9 @@ class Application(object):
 		except UnicodeError as err:
 			print(_("Warning: Unicode problem with directory name..."))
 			return
+		enable_save = False
 		for filename in dir_content:
-			if self.stopped:
+			if self.stopped != 0:
 				return
 			filename = os.path.join(directory, filename)
 			if os.path.isfile(filename):
@@ -413,11 +450,26 @@ class Application(object):
 						title = "Untitled"
 					display_filename = filename.replace(self.search_path.get(), '')
 					self.listbox.insert('end', "%s" % display_filename)
+					self.savestring = self.savestring + filename + "\n"
+					if enable_save == False:
+						self.save_button["state"] = NORMAL
+						enable_save = True
 					self.match_count = self.match_count + 1
 			elif os.path.isdir(filename) and not os.path.islink(filename):
 				self.recursiveSearch(filename)
 		return
 
+	def doSave(self):
+		savestring = _("Search path:") + " " + self.search_path.get() + "\n"
+		savestring = savestring + _("Search terms:") + " " + self.search_query.get() + "\n"
+		savestring = savestring + _("Mode:") + " " + self.mode_button["text"] + "\n\n"
+		savestring = savestring + _("Results:") + "\n" + self.savestring
+		fo = tkinter.filedialog.asksaveasfile()
+		fo.write(savestring)
+		self.stopped = 1
+		self.save_button["state"] = DISABLED
+		return
+
 # Begin gettext integration
 class TranslationIntegration(object):
 	"""GNU-gettext for GNU/Linux"""
@@ -503,7 +555,7 @@ class TranslationIntegration(object):
 
 if __name__ == "__main__":
 
-	version = "0.7.3"
+	version = "0.8.0"
 	loookversion = "loook-" + version
 	
 	g = TranslationIntegration(loookversion) 
